@@ -1,10 +1,10 @@
 #ifndef _FLAGS_H
 #define _FLAGS_H
 
-#include <string>
-
 #include "defs.h"
 
+#include <string>
+
 struct Flags {
 	int width = 1280, height = 720;
 	std::string stream_source;
@@ -15,6 +15,8 @@ struct Flags {
 	uint16_t http_port = DEFAULT_HTTPD_PORT;
 	double output_framerate = 60000.0 / 1001.0;
 	std::string tally_url;
+	double cue_point_padding_seconds = 0.0;  // Can be changed in the menus.
+	bool cue_point_padding_set = false;
 };
 extern Flags global_flags;
 
@@ -24,6 +26,6 @@ extern Flags global_flags;
 extern int flow_initialized_interpolation_quality;
 
 void usage();
-void parse_flags(int argc, char * const argv[]);
+void parse_flags(int argc, char *const argv[]);
 
 #endif  // !defined(_FLAGS_H)
